==> gwenview-4.8.5.tar.xz: gwenview-4.8.5/app/fullscreencontent.h <==
// vim: set tabstop=4 shiftwidth=4 expandtab:
/*
Gwenview: an image viewer
Copyright 2008 Aurélien Gâteau <agateau@kde.org>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA.

*/
#ifndef FULLSCREENCONTENT_H
#define FULLSCREENCONTENT_H

// Qt
#include <QWidget>

// KDE

// Local

class QStringList;

class KActionCollection;
class KUrl;

namespace Gwenview
{

class FullScreenBar;
class SlideShow;

class ThumbnailBarView;

struct FullScreenContentPrivate;
/**
 * The content of the fullscreen bar
 */
class FullScreenContent : public QObject
{
    Q_OBJECT
public:
    FullScreenContent(FullScreenBar* parent, KActionCollection*, SlideShow*);
    ~FullScreenContent();

    ThumbnailBarView* thumbnailBar() const;

    void setCurrentUrl(const KUrl&);

protected:
    bool eventFilter(QObject*, QEvent*);

private Q_SLOTS:
    void updateInformationLabel();
    void updateMetaInfoDialog();
    void showImageMetaInfoDialog();
    void slotPreferredMetaInfoKeyListChanged(const QStringList& list);
    void showFullScreenConfigDialog();
    void updateSlideShowIntervalLabel();
    void setCurrentFullScreenTheme(const QString& themeName);
    void setFullScreenBarHeight(int value);
    void enableAutoHiding();
    void slotShowThumbnailsToggled(bool value);

private:
    FullScreenContentPrivate* const d;
};

} // namespace

#endif /* FULLSCREENCONTENT_H */

==> gwenview-4.8.90.tar.xz: gwenview-4.8.90/app/fullscreencontent.h <==
// vim: set tabstop=4 shiftwidth=4 expandtab:
/*
Gwenview: an image viewer
Copyright 2008 Aurélien Gâteau <agateau@kde.org>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA.

*/
#ifndef FULLSCREENCONTENT_H
#define FULLSCREENCONTENT_H

// Qt
#include <QWidget>

// KDE

// Local

class QStringList;

class KActionCollection;
class KUrl;

namespace Gwenview
{

class FullScreenBar;
class SlideShow;

class ThumbnailBarView;

struct FullScreenContentPrivate;
/**
 * The content of the fullscreen bar
 */
class FullScreenContent : public QObject
{
    Q_OBJECT
public:
    FullScreenContent(QObject* parent);
    ~FullScreenContent();

    void init(KActionCollection*, QWidget* autoHideParentWidget, SlideShow*);

    ThumbnailBarView* thumbnailBar() const;

    void setCurrentUrl(const KUrl&);

    void setDistractionFreeMode(bool);

    void setFullScreenMode(bool);

private Q_SLOTS:
    void updateCurrentUrlWidgets();
    void updateInformationLabel();
    void updateMetaInfoDialog();
    void updateWidgetMask();
    void showImageMetaInfoDialog();
    void slotPaletteChanged();
    void slotImageMetaInfoDialogClosed();
    void slotPreferredMetaInfoKeyListChanged(const QStringList& list);
    void showOptionsMenu();
    void updateSlideShowIntervalLabel();
    void setFullScreenBarHeight(int value);
    void slotShowThumbnailsToggled(bool value);
    void slotViewModeActionToggled(bool value);

private:
    FullScreenContentPrivate* const d;
};

} // namespace

#endif /* FULLSCREENCONTENT_H */
